@@ -10,12 +10,22 @@ mod tests {
             jar.get("first_visit_datetime_pc").map(|c| c.value()),
             Some("2021-07-19+10%3A48%3A50")
         );
+        assert_eq!(
+            jar.get("first_visit_datetime_pc")
+                .map(|c| c.http_only())
+                .flatten(),
+            None
+        );
         assert!(jar.get("p_ab_id").map(|c| c.secure()).flatten().unwrap());
         assert_eq!(
             jar.get("PHPSESSID")
                 .map(|c| c.expires_datetime().unwrap().unix_timestamp()),
             Some(1626662932)
         );
+        assert_eq!(
+            jar.get("PHPSESSID").map(|c| c.http_only()).flatten(),
+            Some(true)
+        );
         assert_eq!(jar.get("yuid_b").map(|c| c.path()).flatten(), Some("/"))
     }
 }
